@@ -37,7 +37,12 @@ def block_split(lines, tag):
     def get_tag_args(line):
         # line = line.strip()
         k = line.find(" ")
+        if 'nodoc' in line:
+            print("Nodoc!!")
         tag_args = ((line[:k + 1] if k >= 0 else line)[len(tag):] ).strip().split(";")
+        if 'nodoc' in tag_args:
+            print("nodoc.")
+
         tag_args = [t.strip() for t in tag_args]
         # if len(tag_args) == 0:
         #     return {'': ''}  # No name.
@@ -46,7 +51,8 @@ def block_split(lines, tag):
 
         if '' not in tag_args:
             tag_args[''] = ''
-
+        if "dse" in tag_args:
+            print("DSE!!!")
         return tag_args
 
     if i is None:
