@@ -7,9 +7,6 @@ from snipper.block_parsing import block_split, block_join
 def fix_f(lines, debug, keep=False):
     lines2 = []
     i = 0
-    # if "GymPacmanEnvironment" in lines[0]:
-    #     print("\n".join(lines))
-    #     z = 324
     while i < len(lines):
         l = lines[i]
         dx = l.find("#!f")
@@ -69,7 +66,7 @@ def fix_f(lines, debug, keep=False):
     return lines2
 
 # stats = {'n': 0}
-def _block_fun(lines, start_extra, end_extra, keep=False, permute=False, questionmarks=False, halfquestionmarks=False, silent=False):
+def _block_fun(lines, start_extra, end_extra, keep=False, permute=False, questionmarks=False, halfquestionmarks=False, silent=False, nolines=False):
     methods = {'remove': 0}
     # if method not in ['remove', 'permute', 'questionmark', 'halfquestionmark']:
     #     assert False
@@ -108,7 +105,12 @@ def _block_fun(lines, start_extra, end_extra, keep=False, permute=False, questio
                 lines = f3(lines)
                 insert_lines = True
             if not insert_lines:
-                lines = [id + f"# TODO: {cc} lines missing."]
+                if nolines:
+                    todo = f"# TODO: Code has been removed from here."
+                else:
+                    todo = f"# TODO: {cc} lines missing."
+
+                lines = [id + todo]
             else:
                 lines = msg + lines
             lines += [id + f'raise NotImplementedError("{ee}")']
