@@ -14,7 +14,7 @@ def rsession(analyzer, lines, extra):
     dbug = False
     # analyzer = we.spawn("python", encoding="utf-8", timeout=20)
     # analyzer.expect([">>>"])
-    if "BetterBasicDog" in "\n".join(lines) and False:
+    if "You can group" in "\n".join(lines): # in "\n".join(lines):
         print("\n".join(lines))
         print("-"*50)
         for k in extra['session_results']:
@@ -23,20 +23,27 @@ def rsession(analyzer, lines, extra):
 
         import time
         an = we.spawn("python", encoding="utf-8", timeout=20)
+        an.setwinsize(400, 400) # set window size to avoid truncated output or input.
         an.expect([">>>"])
         l3 = """
-import numpy as np 
-from scipy.linalg import norm
-x = np.asarray([3, 4])
-x  # What is x?
-norm(x)"""
+2 + 4 # Add two integers
+50 - 5 * 6
+(2 + 2) * (3 - 1) # You can group operations using parenthesis
+width = 20 # Assign the variable 'width' to a value of 20
+height = 5*9 # And also height is assigned the value of 5 * 9 = 45
+area = 2*3 # Compute the area of a rectangle and assign it to area now the text will be longer is that an issue
+area # This line shows us the value of 'area' #!i=b
+"""
         lines2 = l3.strip().splitlines()
+        from collections import defaultdict
+        dd = defaultdict(list)
 
         for l in lines2:
-            an.sendline(l)
+            dd['code'].append(l)
+            an.sendline(l.rstrip())
             an.expect_exact([">>>", "..."])
-            print("INPUT", l)
-            print(">>>", an.before.strip())
+            dd["output"].append(an.before.strip())
+            # print(">>>", an.before.strip())
             if len(an.after.strip()) > 4:
                 print(">>>>>>>>>>>>> That was a long after?")
             # analyzer.be
@@ -44,6 +51,9 @@ norm(x)"""
         print('*' * 50)
         # analyzer = an
         dbug = True
+        import tabulate
+        print(tabulate.tabulate(dd, headers='keys'))
+
     lines = "\n".join(lines).replace("\r", "").splitlines()
 
     for i, l in enumerate(lines):
@@ -68,16 +78,15 @@ norm(x)"""
         while True:
             time.sleep(0.05)
             analyzer.expect_exact([">>>", "..."])
-            if dbug and "total_cost" in word:
-                aaa = 23234
+            # if dbug and "total_cost" in word:
+            #     aaa = 23234
             before += analyzer.before
             # if dbug:
-            print(">  analyzer.before...", analyzer.before.strip(), "...AFTER...", analyzer.after.strip())
+            # print(">  analyzer.before...", analyzer.before.strip(), "...AFTER...", analyzer.after.strip())
             # AFTER =
             if analyzer.before.endswith("\n"):
-                print("> BREAKING LOOP")
+                # print("> BREAKING LOOP")
                 break
-                pass
             else:
                 before += analyzer.after
             break
@@ -108,6 +117,8 @@ norm(x)"""
 
 
 def run_i(lines, file, output):
+    if 'python0A' in str(file):
+        print(234)
     extra = dict(python=None, output=output, evaluated_lines=0, session_results=[])
     def block_fun(lines, start_extra, end_extra, art, head="", tail="", output=None, extra=None):
         outf = output + ("_" + art if art is not None and len(art) > 0 else "") + ".shell"
@@ -119,6 +130,7 @@ def run_i(lines, file, output):
 
         if extra['python'] is None:
             an = we.spawn("python", encoding="utf-8", timeout=20)
+            an.setwinsize(400, 400)  # set window size to avoid truncated output or input.
             an.expect([">>>"])
             extra['python'] = an
 
@@ -141,8 +153,8 @@ def run_i(lines, file, output):
             for outf in kvs:
                 out = "\n".join( ["\n".join(v[1]) for v in c if v[0] == outf] )
                 out = out.replace("\r", "")
-                if outf.endswith("python0B_e4.shell"):
-                    print(outf)
+                # if outf.endswith("python0B_e4.shell"):
+                #     print(outf)
 
                 with open(outf, 'w') as f:
                     f.write(out)
