@@ -30,9 +30,9 @@ def get_aux(auxfile):
         if not os.path.dirname(auxdir):
             print("Directory for auxfile does not exist:", auxdir)
         else:
-            print("Auxfile did not exist, but directory did. Printing the contents:")
-            for f in glob.glob(os.path.dirname(auxfile) + "/*"):
-                print(f)
+            print("Auxfile did not exist, but directory did. Probably missing latex compile command.")
+            # for f in glob.glob(os.path.dirname(auxfile) + "/*"):
+            #     print(f)
 
         return {}
 
