@@ -20,7 +20,7 @@ def snip_dir(source_dir,  # Sources
              verbose=True,
              ):
 
-    print("Snipper fixing", source_dir)
+    print(f"Snipper fixing {source_dir} {cut_files=}, {censor_files=}, {output_dir=}")
     if dest_dir == None:
         dest_dir = tempfile.mkdtemp()
         print("[snipper]", "no destination dir was specified so using nonsense destination:", dest_dir)
@@ -109,5 +109,5 @@ def snip_dir(source_dir,  # Sources
             else:
                 if os.path.isdir(rm_file+"/"):
                     shutil.rmtree(rm_file)
-    print("[snipper]", "done")
+    # print("[snipper]", "done")
     return n, cutouts
