@@ -48,8 +48,8 @@ def censor_file(file, run_files=True, run_out_dirs=None, cut_files=True,
         s = s.lstrip()
         lines = s.split("\n")
         for k, l in enumerate(lines):
-            if l.find(" # !") > 0:
-                print(f"{file}:{k}> bad snipper tag, fixing")
+            # if l.find(" # !") > 0:
+            #     print(f"{file}:{k}> bad snipper tag, fixing")
             lines[k] = l.replace("# !", "#!")
 
         try:
